@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARCONFIGURESETTINGSWIDGET_H
-#define GRAVATARCONFIGURESETTINGSWIDGET_H
+#pragma once
 
 #include "gravatar_export.h"
 #include <QWidget>
@@ -20,7 +19,7 @@ class GRAVATAR_EXPORT GravatarConfigureSettingsWidget : public QWidget
     Q_OBJECT
 public:
     explicit GravatarConfigureSettingsWidget(QWidget *parent = nullptr);
-    ~GravatarConfigureSettingsWidget();
+    ~GravatarConfigureSettingsWidget() override;
     void slotRestoreDefault();
     void save();
     void load();
@@ -34,5 +33,3 @@ private:
     QCheckBox *mFallbackGravatar = nullptr;
 };
 }
-
-#endif // GRAVATARCONFIGURESETTINGSWIDGET_H
